@@ -24,6 +24,7 @@ __all__ = (
     "ArtifactPackagingType",
     "ArtifactsTypeType",
     "AuthTypeType",
+    "BatchReportModeTypeType",
     "BucketOwnerAccessType",
     "BuildBatchPhaseTypeType",
     "BuildPhaseTypeType",
@@ -78,6 +79,7 @@ ArtifactNamespaceType = Literal["BUILD_ID", "NONE"]
 ArtifactPackagingType = Literal["NONE", "ZIP"]
 ArtifactsTypeType = Literal["CODEPIPELINE", "NO_ARTIFACTS", "S3"]
 AuthTypeType = Literal["BASIC_AUTH", "OAUTH", "PERSONAL_ACCESS_TOKEN"]
+BatchReportModeTypeType = Literal["REPORT_AGGREGATED_BATCH", "REPORT_INDIVIDUAL_BUILDS"]
 BucketOwnerAccessType = Literal["FULL", "NONE", "READ_ONLY"]
 BuildBatchPhaseTypeType = Literal[
     "COMBINE_ARTIFACTS",
